@@ -12,7 +12,7 @@ import os
 
 init() #colorama
 
-print(os.getcwd())
+
 
 def createCBRole(projName):
     try:
@@ -249,6 +249,7 @@ def addToBSpec(env_name, allorOne, funName):
 @click.option('--skip', '-s', is_flag=True)
 @click.option('--buildspec', '-b')
 def main(skip, buildspec):
+    print(f"THIS : -> {os.getcwd()}\n\n")
     print(f"{Fore.CYAN}========SLS Manager v 0.1.0========{Style.RESET_ALL}")
     slsPath = Path('serverless.yml')
     if not slsPath.exists():
